==> opennms-webapp-1.3.3-sources.jar: org/opennms/web/admin/nodeManagement/ManagedService.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// 2004 Jan 06: Added support for STATUS_SUSPEND and STATUS_RESUME
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.web.admin.nodeManagement;

/**
 * @author <A HREF="mailto:jason@opennms.org">Jason Johns </A>
 * @author <A HREF="http://www.opennms.org/">OpenNMS </A>
 */
public class ManagedService {
    /**
     * 
     */
    protected String name;

    /**
     * 
     */
    protected String status;

    /**
     * 
     */
    protected int serviceId;

    /**
     */
    public ManagedService() {
    }

    /**
     * 
     */
    public void setId(int id) {
        serviceId = id;
    }

    /**
     */
    public int getId() {
        return serviceId;
    }

    /**
     * 
     */
    public void setName(String newName) {
        name = newName;
    }

    /**
     */
    public String getName() {
        return name;
    }

    /**
     * 
     */
    public void setStatus(String newStatus) {
        if (newStatus.equals("A")) {
            status = "managed";
        } else if (newStatus.equals("R")) {
            status = "managed";
        } else {
            status = "unmanaged";
        }
    }

    /**
     * 
     */
    public String getStatus() {
        return status;
    }
}

==> opennms-webapp-1.9.6-sources.jar: org/opennms/web/admin/nodeManagement/ManagedService.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// 2004 Jan 06: Added support for STATUS_SUSPEND and STATUS_RESUME
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.web.admin.nodeManagement;

/**
 * <p>ManagedService class.</p>
 *
 * @author <A HREF="mailto:jason@opennms.org">Jason Johns </A>
 * @author <A HREF="http://www.opennms.org/">OpenNMS </A>
 * @author <A HREF="mailto:jason@opennms.org">Jason Johns </A>
 * @author <A HREF="http://www.opennms.org/">OpenNMS </A>
 * @version $Id: $
 * @since 1.8.1
 */
public class ManagedService {
    /**
     * 
     */
    protected String name;

    /**
     * 
     */
    protected String status;

    /**
     * 
     */
    protected int serviceId;

    /**
     * <p>Constructor for ManagedService.</p>
     */
    public ManagedService() {
    }

    /**
     * <p>setId</p>
     *
     * @param id a int.
     */
    public void setId(int id) {
        serviceId = id;
    }

    /**
     * <p>getId</p>
     *
     * @return a int.
     */
    public int getId() {
        return serviceId;
    }

    /**
     * <p>Setter for the field <code>name</code>.</p>
     *
     * @param newName a {@link java.lang.String} object.
     */
    public void setName(String newName) {
        name = newName;
    }

    /**
     * <p>Getter for the field <code>name</code>.</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getName() {
        return name;
    }

    /**
     * <p>Setter for the field <code>status</code>.</p>
     *
     * @param newStatus a {@link java.lang.String} object.
     */
    public void setStatus(String newStatus) {
        if (newStatus.equals("A")) {
            status = "managed";
        } else if (newStatus.equals("R")) {
            status = "managed";
        } else {
            status = "unmanaged";
        }
    }

    /**
     * <p>Getter for the field <code>status</code>.</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getStatus() {
        return status;
    }
}
